@@ -49,12 +49,11 @@ bool AudioSampler::init(const SamplerParameters& params) {
   }
 
 #if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(57, 28, 100)
-  SwrContext* swrContext_ = NULL;
   AVChannelLayout channel_out;
   AVChannelLayout channel_in;
   av_channel_layout_default(&channel_out, params.out.audio.channels);
   av_channel_layout_default(&channel_in, params.in.audio.channels);
-  swr_alloc_set_opts2(
+  int ret = swr_alloc_set_opts2(
       &swrContext_,
       &channel_out,
       (AVSampleFormat)params.out.audio.format,
@@ -64,6 +63,10 @@ bool AudioSampler::init(const SamplerParameters& params) {
       params.in.audio.samples,
       0,
       logCtx_);
+  if (ret < 0 || swrContext_ == nullptr) {
+    LOG(ERROR) << "Cannot allocate SwrContext";
+    return false;
+  }
 #else
   swrContext_ = swr_alloc_set_opts(
       nullptr,
@@ -75,11 +78,11 @@ bool AudioSampler::init(const SamplerParameters& params) {
       params.in.audio.samples,
       0,
       logCtx_);
-#endif
   if (swrContext_ == nullptr) {
     LOG(ERROR) << "Cannot allocate SwrContext";
     return false;
   }
+#endif
 
   int result;
   if ((result = swr_init(swrContext_)) < 0) {
